==> php-residence_0.2.4.tar.gz: php-residence/includes/dati_form_prenotazione.php <==
<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

echo "
<input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
<input type=\"hidden\" name=\"origine\" value=\"$origine\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"cognome\" value=\"$cognome\">
<input type=\"hidden\" name=\"inizioperiodo\" value=\"$inizioperiodo\">
<input type=\"hidden\" name=\"fineperiodo\" value=\"$fineperiodo\">
<input type=\"hidden\" name=\"appartamento\" value=\"$appartamento\">
<input type=\"hidden\" name=\"nometipotariffa\" value=\"$nometipotariffa\">
<input type=\"hidden\" name=\"numpersone\" value=\"$numpersone\">
<input type=\"hidden\" name=\"numcostifinali\" value=\"$numcostifinali\">
<input type=\"hidden\" name=\"numcostisettimanali\" value=\"$numcostisettimanali\">
<input type=\"hidden\" name=\"numcostipercentuali\" value=\"$numcostipercentuali\">
<input type=\"hidden\" name=\"assegnazioneapp\" value=\"$assegnazioneapp\">
<input type=\"hidden\" name=\"sconto\" value=\"$sconto\">
<input type=\"hidden\" name=\"commento\" value=\"$commento\">
<input type=\"hidden\" name=\"lista_app\" value=\"$lista_app\">
<input type=\"hidden\" name=\"caparra\" value=\"$caparra\">
<input type=\"hidden\" name=\"occupare_app_agenzia_sempre\" value=\"$occupare_app_agenzia_sempre\">
<input type=\"hidden\" name=\"spezzetta\" value=\"$spezzetta\">";
for ($numcf = 1 ; $numcf <= $numcostifinali ; $numcf = $numcf + 1) {
$costofinale = "costofinale" . $numcf ;
$valcostofinale = $$costofinale ;
$nummoltiplica_cf = "nummoltiplica_cf" . $numcf;
$valnummoltiplica_cf = $$nummoltiplica_cf;
echo "
<input type=\"hidden\" name=\"$costofinale\" value=\"$valcostofinale\">
<input type=\"hidden\" name=\"$nummoltiplica_cf\" value=\"$valnummoltiplica_cf\">";
} # fine for $numcf
for ($numcs = 1 ; $numcs <= $numcostisettimanali ; $numcs = $numcs + 1) {
$costosettimanale = "costosettimanale" . $numcs ;
$numsettimane = "numsettimane" . $numcs ;
$valcostosettimanale = $$costosettimanale ;
$valnumsettimane = $$numsettimane ;
$nummoltiplica_cs = "nummoltiplica_cs" . $numcs;
$valnummoltiplica_cs = $$nummoltiplica_cs;
echo "
<input type=\"hidden\" name=\"$costosettimanale\" value=\"$valcostosettimanale\">
<input type=\"hidden\" name=\"$numsettimane\" value=\"$valnumsettimane\">
<input type=\"hidden\" name=\"$nummoltiplica_cs\" value=\"$valnummoltiplica_cs\">";
} # fine for $numcs
for ($numcp = 1 ; $numcp <= $numcostipercentuali ; $numcp = $numcp + 1) {
$costopercentuale = "costopercentuale" . $numcp ;
$valcostopercentuale = $$costopercentuale ;
$nummoltiplica_cp = "nummoltiplica_cp" . $numcp;
$valnummoltiplica_cp = $$nummoltiplica_cp;
echo "
<input type=\"hidden\" name=\"$costopercentuale\" value=\"$valcostopercentuale\">
<input type=\"hidden\" name=\"$nummoltiplica_cp\" value=\"$valnummoltiplica_cp\">";
} # fine for $numcp


?>

==> php-residence_0.3.tar.gz: php-residence/includes/dati_form_prenotazione.php <==
<?php

#################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

echo "
<input type=\"hidden\" name=\"cognome\" value=\"$cognome\">
<input type=\"hidden\" name=\"inizioperiodo\" value=\"$inizioperiodo\">
<input type=\"hidden\" name=\"fineperiodo\" value=\"$fineperiodo\">
<input type=\"hidden\" name=\"appartamento\" value=\"$appartamento\">
<input type=\"hidden\" name=\"nometipotariffa\" value=\"$nometipotariffa\">
<input type=\"hidden\" name=\"numpersone\" value=\"$numpersone\">
<input type=\"hidden\" name=\"numcostifinali\" value=\"$numcostifinali\">
<input type=\"hidden\" name=\"numcostisettimanali\" value=\"$numcostisettimanali\">
<input type=\"hidden\" name=\"numcostipercentuali\" value=\"$numcostipercentuali\">
<input type=\"hidden\" name=\"assegnazioneapp\" value=\"$assegnazioneapp\">
<input type=\"hidden\" name=\"sconto\" value=\"$sconto\">
<input type=\"hidden\" name=\"conferma_prenota\" value=\"$conferma_prenota\">
<input type=\"hidden\" name=\"commento\" value=\"$commento\">
<input type=\"hidden\" name=\"lista_app\" value=\"$lista_app\">
<input type=\"hidden\" name=\"caparra\" value=\"$caparra\">
<input type=\"hidden\" name=\"occupare_app_agenzia_sempre\" value=\"$occupare_app_agenzia_sempre\">
<input type=\"hidden\" name=\"spezzetta\" value=\"$spezzetta\">";
for ($numcf = 1 ; $numcf <= $numcostifinali ; $numcf = $numcf + 1) {
$costofinale = "costofinale" . $numcf ;
$valcostofinale = $$costofinale ;
$nummoltiplica_cf = "nummoltiplica_cf" . $numcf;
$valnummoltiplica_cf = $$nummoltiplica_cf;
echo "
<input type=\"hidden\" name=\"$costofinale\" value=\"$valcostofinale\">
<input type=\"hidden\" name=\"$nummoltiplica_cf\" value=\"$valnummoltiplica_cf\">";
} # fine for $numcf
for ($numcs = 1 ; $numcs <= $numcostisettimanali ; $numcs = $numcs + 1) {
$costosettimanale = "costosettimanale" . $numcs ;
$numsettimane = "numsettimane" . $numcs ;
$valcostosettimanale = $$costosettimanale ;
$valnumsettimane = $$numsettimane ;
$nummoltiplica_cs = "nummoltiplica_cs" . $numcs;
$valnummoltiplica_cs = $$nummoltiplica_cs;
echo "
<input type=\"hidden\" name=\"$costosettimanale\" value=\"$valcostosettimanale\">
<input type=\"hidden\" name=\"$numsettimane\" value=\"$valnumsettimane\">
<input type=\"hidden\" name=\"$nummoltiplica_cs\" value=\"$valnummoltiplica_cs\">";
} # fine for $numcs
for ($numcp = 1 ; $numcp <= $numcostipercentuali ; $numcp = $numcp + 1) {
$costopercentuale = "costopercentuale" . $numcp ;
$valcostopercentuale = $$costopercentuale ;
$nummoltiplica_cp = "nummoltiplica_cp" . $numcp;
$valnummoltiplica_cp = $$nummoltiplica_cp;
echo "
<input type=\"hidden\" name=\"$costopercentuale\" value=\"$valcostopercentuale\">
<input type=\"hidden\" name=\"$nummoltiplica_cp\" value=\"$valnummoltiplica_cp\">";
} # fine for $numcp


?>
